==> rc-ui-lib-0.1.29.tgz: package/es/tabs/TabsTitle.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useMemo, forwardRef } from 'react';
import classnames from 'classnames';
import { isDef, createNamespace } from '../utils';
import Badge from '../badge';

var _createNamespace = createNamespace('tab'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var TabsTitle = /*#__PURE__*/forwardRef(function (props, ref) {
  var type = props.type,
      color = props.color,
      isActive = props.isActive,
      activeColor = props.activeColor,
      inactiveColor = props.inactiveColor,
      disabled = props.disabled,
      className = props.className;
  var customStyle = useMemo(function () {
    var style = {};
    var isCard = type === 'card'; // card theme color

    if (color && isCard) {
      style.borderColor = color;

      if (!disabled) {
        if (isActive) {
          style.backgroundColor = color;
        } else {
          style.color = color;
        }
      }
    }

    var titleColor = isActive ? activeColor : inactiveColor;

    if (titleColor) {
      style.color = titleColor;
    }

    return style;
  }, [type, color, disabled, isActive, activeColor, inactiveColor]);

  var renderText = function renderText() {
    var Text = /*#__PURE__*/React.createElement("span", {
      className: classnames(bem('text', {
        ellipsis: !props.scrollable
      }))
    }, function () {
      if (typeof props.renderTitle === 'function') {
        return props.renderTitle(isActive);
      }

      return props.renderTitle || props.title;
    }());

    if (props.dot || isDef(props.badge) && props.badge !== '') {
      return /*#__PURE__*/React.createElement(Badge, {
        dot: props.dot,
        content: props.badge,
        showZero: props.showZeroBadge
      }, Text);
    }

    return Text;
  };

  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    className: classnames([bem({
      active: props.isActive,
      disabled: props.disabled
    }), className]),
    style: customStyle,
    "aria-selected": props.isActive,
    onClick: props.onClick
  }, renderText());
});
TabsTitle.defaultProps = {
  showZeroBadge: true
};
export default TabsTitle;

==> rc-ui-lib-0.1.41.tgz: package/es/tabs/TabsTitle.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useMemo, forwardRef, useContext } from 'react';
import classnames from 'classnames';
import { isDef } from '../utils';
import Badge from '../badge';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var TabsTitle = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('tab', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var type = props.type,
      color = props.color,
      isActive = props.isActive,
      activeColor = props.activeColor,
      inactiveColor = props.inactiveColor,
      disabled = props.disabled,
      className = props.className;
  var customStyle = useMemo(function () {
    var style = {};
    var isCard = type === 'card'; // card theme color

    if (color && isCard) {
      style.borderColor = color;

      if (!disabled) {
        if (isActive) {
          style.backgroundColor = color;
        } else {
          style.color = color;
        }
      }
    }

    var titleColor = isActive ? activeColor : inactiveColor;

    if (titleColor) {
      style.color = titleColor;
    }

    return style;
  }, [type, color, disabled, isActive, activeColor, inactiveColor]);

  var renderText = function renderText() {
    var Text = /*#__PURE__*/React.createElement("span", {
      className: classnames(bem('text', {
        ellipsis: !props.scrollable
      }))
    }, function () {
      if (typeof props.renderTitle === 'function') {
        return props.renderTitle(isActive);
      }

      return props.renderTitle || props.title;
    }());

    if (props.dot || isDef(props.badge) && props.badge !== '') {
      return /*#__PURE__*/React.createElement(Badge, {
        dot: props.dot,
        content: props.badge,
        showZero: props.showZeroBadge
      }, Text);
    }

    return Text;
  };

  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    className: classnames([bem({
      active: props.isActive,
      disabled: props.disabled
    }), className]),
    style: customStyle,
    "aria-selected": props.isActive,
    onClick: props.onClick
  }, renderText());
});
TabsTitle.defaultProps = {
  showZeroBadge: true
};
export default TabsTitle;
